@@ -1,12 +1,10 @@
 import os
+import shutil
 from pathlib import Path
 
-import pytest
-
 from micro_toolkit.cache.cache_me import cache_me
 
 
-@pytest.mark.skip("need fix")
 def test_cache_me():
     func_run_flag = False
 
@@ -21,7 +19,7 @@ def test_cache_me():
     # # remove cache file in case of multi running with crash
     current_path = Path(os.path.dirname(os.path.realpath(__file__)))
     cache_path = current_path / ".cache"
-    cache_path.rmdir()
+    shutil.rmtree(cache_path)
 
     result = func()
 
@@ -37,4 +35,4 @@ def test_cache_me():
     assert result == "hello, world"
 
     # clean up
-    cache_path.rmdir()
+    shutil.rmtree(cache_path)
